==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/misc/WheelchairEntity.java <==
package cc.thonly.reverie_dreams.entity.misc;

import cc.thonly.polymer.entity.WheelChairImpl;
import cc.thonly.reverie_dreams.block.ModBlocks;
import cc.thonly.reverie_dreams.server.PlayerInputManager;
import eu.pb4.polymer.core.api.entity.PolymerEntity;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;
import net.minecraft.class_11368;
import net.minecraft.class_11372;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1282;
import net.minecraft.class_1293;
import net.minecraft.class_1294;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1313;
import net.minecraft.class_1314;
import net.minecraft.class_1316;
import net.minecraft.class_1324;
import net.minecraft.class_1347;
import net.minecraft.class_1429;
import net.minecraft.class_1542;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_241;
import net.minecraft.class_243;
import net.minecraft.class_2945;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_5131;
import net.minecraft.class_5132;
import net.minecraft.class_5134;
import net.minecraft.entity.*;
import org.jetbrains.annotations.Nullable;

@Setter
@Getter
@ToString
public class WheelchairEntity extends class_1314 implements class_1316 {
    public String ownerUUID = "";

    public WheelchairEntity(class_1299<? extends class_1314> entityType, class_1937 world) {
        super(entityType, world);
        class_5131 attributes = this.method_6127();
        class_1324 scaleInstance = attributes.method_45329(class_5134.field_47760);
        if (scaleInstance != null) {
            scaleInstance.method_6192(0.25);
        }
    }

    public WheelchairEntity(class_1299<? extends class_1314> entityType, class_1937 world, int x, int y, int z) {
        this(entityType, world);
        this.method_5814(x, y, z);
    }

    public WheelchairEntity(class_1299<? extends class_1314> entityType, class_1937 world, int x, int y, int z, String ownerUUID) {
        this(entityType, world, x, y, z);
        this.ownerUUID = ownerUUID;
    }

    @Override
    protected void method_5693(class_2945.class_9222 builder) {
        super.method_5693(builder);
    }

    @Override
    protected void method_5959() {
        super.method_5959();
        this.field_6201.method_6277(0, new class_1347(this));
    }

    @Override
    public void method_5773() {
        super.method_5773();
        if (!(this.method_37908() instanceof class_3218 world)) {
            return;
        }
        if (!this.method_6059(class_1294.field_5905)) {
            this.method_6092(new class_1293(class_1294.field_5905, Integer.MAX_VALUE, 0, false, false));
        }
    }

    @Override
    public void method_5837(class_3222 player) {
        super.method_5837(player);
        PolymerEntity polymerEntity = PolymerEntity.get(this);
        if (polymerEntity instanceof WheelChairImpl impl) {
            impl.onTrackingStopped(player);
            impl.onCreated();
        }
    }

    @Override
    public void method_5742(class_3222 player) {
        super.method_5742(player);
        PolymerEntity polymerEntity = PolymerEntity.get(this);
        if (polymerEntity instanceof WheelChairImpl impl) {
            impl.onTrackingStopped(player);
        }
    }

    @Override
    public boolean method_64397(class_3218 world, class_1282 source, float amount) {
        class_1297 attacker = source.method_5529();
        if (attacker != null && attacker.method_5715() && this.ownerUUID.equalsIgnoreCase(attacker.method_5845())) {
                class_1542 itemEntity = new class_1542(world, this.method_23317(), this.method_23318(), this.method_23321(), new class_1799(ModBlocks.WHEEL_CHAIR));
                world.method_8649(itemEntity);
                this.method_31472();
        }
        return super.method_64397(world, source, amount);
    }

    @Override
    @Nullable
    public class_1309 method_5642() {
        class_1657 playerEntity;
        class_1297 entity;
        if ((entity = this.method_31483()) instanceof class_1657 && (playerEntity = (class_1657) entity).method_5805()) {
            return playerEntity;
        }
        return super.method_5642();
    }

    @Override
    protected void method_49481(class_1657 controllingPlayer, class_243 movementInput) {
        super.method_49481(controllingPlayer, movementInput);
        class_241 vec2f = this.getControlledRotation(controllingPlayer);
        this.method_5710(vec2f.field_1342, vec2f.field_1343);
        this.field_6283 = this.field_6241 = this.method_36454();
        this.field_6283 = controllingPlayer.method_43078();
        this.field_6220 = this.field_6283;

        if (controllingPlayer instanceof class_3222 player) {
            boolean keyLeft = PlayerInputManager.isKeyDown(player, PlayerInputManager.InputKey.LEFT);
            boolean keyRight = PlayerInputManager.isKeyDown(player, PlayerInputManager.InputKey.RIGHT);
            boolean keyForward = PlayerInputManager.isKeyDown(player, PlayerInputManager.InputKey.FORWARD);
            boolean keyBack = PlayerInputManager.isKeyDown(player, PlayerInputManager.InputKey.BACKWARD);
            boolean keySpeedUp = PlayerInputManager.isKeyDown(player, PlayerInputManager.InputKey.SPRINT);

            float strafe = keyLeft ? 0.5f : (keyRight ? -0.5f : 0);
            float forward = keyForward ? 3 : (keyBack ? -0.5f : 0);

            float speedMultiplier = keySpeedUp ? 1.8f : 1.0f;

            this.method_5724(0.245f * speedMultiplier, new class_243(strafe, -1, forward));
            this.method_5784(class_1313.field_6308, this.method_18798());
            this.field_6007 = true;
        }
    }

    @Override
    public boolean method_5740() {
        return false;
    }

    protected class_241 getControlledRotation(class_1309 controllingPassenger) {
        return new class_241(controllingPassenger.method_36455() * 0.5f, controllingPassenger.method_36454());
    }

    @Override
    protected class_243 method_49482(class_1657 controllingPlayer, class_243 movementInput) {
        float f = controllingPlayer.field_6212 * 0.5f;
        float g = controllingPlayer.field_6250;
        if (g <= 0.0f) {
            g *= 0.25f;
        }
        return new class_243(f, 0.0, g);
    }

    @Override
    public void method_6078(class_1282 damageSource) {
        super.method_6078(damageSource);
        class_1937 world = this.method_37908();
        class_1542 itemEntity = new class_1542(world, this.method_23317(), this.method_23318(), this.method_23321(), new class_1799(ModBlocks.WHEEL_CHAIR));
        world.method_8649(itemEntity);
    }

    @Override
    public class_1269 method_5992(class_1657 player, class_1268 hand) {
        class_1937 world = player.method_37908();
        if (!this.method_5782() && !player.method_21823()) {
            if (!this.method_37908().field_9236) {
                player.method_5804(this);
            }
            return class_1269.field_5812;
        }
        return super.method_5992(player, hand);
    }

    public static class_5132 createAttributes() {
        return class_1429.method_61457()
                .method_26868(class_5134.field_23716, 20.0)
                .method_26868(class_5134.field_23719, 0.25)
                .method_26868(class_5134.field_23720, 0.15)
                .method_26868(class_5134.field_23718, 10.0)
                .method_26866();
    }

    @Override
    protected void method_5652(class_11372 view) {
        super.method_5652(view);
        view.method_71469("OwnerUUID", this.ownerUUID);
    }

    @Override
    protected void method_5749(class_11368 view) {
        super.method_5749(view);
        this.ownerUUID = view.method_71428("OwnerUUID", "null");
    }
    @Override
    public void method_6154(int strength) {

    }

    @Override
    public boolean method_6153() {
        return this.method_24828();
    }

    @Override
    public void method_6155(int height) {
        if (this.method_24828()) {
            this.method_5762(0, 0.42D, 0);
        }
    }


    @Override
    public void method_6156() {

    }
}

==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/misc/WheelchairEntity.java <==
package cc.thonly.reverie_dreams.entity.misc;

import cc.thonly.polymer.entity.WheelChairImpl;
import cc.thonly.reverie_dreams.registry.content.block.RDBlocks;
import cc.thonly.reverie_dreams.server.PlayerInputManager;
import eu.pb4.polymer.core.api.entity.PolymerEntity;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;
import net.minecraft.class_11368;
import net.minecraft.class_11372;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1282;
import net.minecraft.class_1293;
import net.minecraft.class_1294;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1313;
import net.minecraft.class_1314;
import net.minecraft.class_1316;
import net.minecraft.class_1324;
import net.minecraft.class_1347;
import net.minecraft.class_1429;
import net.minecraft.class_1542;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_241;
import net.minecraft.class_243;
import net.minecraft.class_2945;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_5131;
import net.minecraft.class_5132;
import net.minecraft.class_5134;
import org.jetbrains.annotations.Nullable;

@Setter
@Getter
@ToString
public class WheelchairEntity extends class_1314 implements class_1316 {
    public String ownerUUID = "";

    public WheelchairEntity(class_1299<? extends class_1314> entityType, class_1937 world) {
        super(entityType, world);
        class_5131 attributes = this.method_6127();
        class_1324 scaleInstance = attributes.method_45329(class_5134.field_47760);
        if (scaleInstance != null) {
            scaleInstance.method_6192(0.25);
        }
    }

    public WheelchairEntity(class_1299<? extends class_1314> entityType, class_1937 world, int x, int y, int z) {
        this(entityType, world);
        this.method_5814(x, y, z);
    }

    public WheelchairEntity(class_1299<? extends class_1314> entityType, class_1937 world, int x, int y, int z, String ownerUUID) {
        this(entityType, world, x, y, z);
        this.ownerUUID = ownerUUID;
    }

    @Override
    protected void method_5693(class_2945.class_9222 builder) {
        super.method_5693(builder);
    }

    @Override
    protected void method_5959() {
        super.method_5959();
        this.field_6201.method_6277(0, new class_1347(this));
    }

    @Override
    public void method_5773() {
        super.method_5773();
        if (!(this.method_37908() instanceof class_3218 world)) {
            return;
        }
        if (!this.method_6059(class_1294.field_5905)) {
            this.method_6092(new class_1293(class_1294.field_5905, Integer.MAX_VALUE, 0, false, false));
        }
    }

    @Override
    public void method_5837(class_3222 player) {
        super.method_5837(player);
        PolymerEntity polymerEntity = PolymerEntity.get(this);
        if (polymerEntity instanceof WheelChairImpl impl) {
            impl.onTrackingStopped(player);
            impl.onCreated();
        }
    }

    @Override
    public void method_5742(class_3222 player) {
        super.method_5742(player);
        PolymerEntity polymerEntity = PolymerEntity.get(this);
        if (polymerEntity instanceof WheelChairImpl impl) {
            impl.onTrackingStopped(player);
        }
    }

    @Override
    public boolean method_64397(class_3218 world, class_1282 source, float amount) {
        class_1297 attacker = source.method_5529();
        if (attacker != null && attacker.method_5715() && this.ownerUUID.equalsIgnoreCase(attacker.method_5845())) {
                class_1542 itemEntity = new class_1542(world, this.method_23317(), this.method_23318(), this.method_23321(), new class_1799(RDBlocks.WHEEL_CHAIR));
                world.method_8649(itemEntity);
                this.method_31472();
        }
        return super.method_64397(world, source, amount);
    }

    @Override
    @Nullable
    public class_1309 method_5642() {
        class_1657 playerEntity;
        class_1297 entity;
        if ((entity = this.method_31483()) instanceof class_1657 && (playerEntity = (class_1657) entity).method_5805()) {
            return playerEntity;
        }
        return super.method_5642();
    }

    @Override
    protected void method_49481(class_1657 controllingPlayer, class_243 movementInput) {
        super.method_49481(controllingPlayer, movementInput);
        class_241 vec2f = this.getControlledRotation(controllingPlayer);
        this.method_5710(vec2f.field_1342, vec2f.field_1343);
        this.field_6283 = this.field_6241 = this.method_36454();
        this.field_6283 = controllingPlayer.method_43078();
        this.field_6220 = this.field_6283;

        if (controllingPlayer instanceof class_3222 player) {
            boolean keyLeft = PlayerInputManager.isKeyDown(player, PlayerInputManager.InputKey.LEFT);
            boolean keyRight = PlayerInputManager.isKeyDown(player, PlayerInputManager.InputKey.RIGHT);
            boolean keyForward = PlayerInputManager.isKeyDown(player, PlayerInputManager.InputKey.FORWARD);
            boolean keyBack = PlayerInputManager.isKeyDown(player, PlayerInputManager.InputKey.BACKWARD);
            boolean keySpeedUp = PlayerInputManager.isKeyDown(player, PlayerInputManager.InputKey.SPRINT);

            float strafe = keyLeft ? 0.5f : (keyRight ? -0.5f : 0);
            float forward = keyForward ? 3 : (keyBack ? -0.5f : 0);

            float speedMultiplier = keySpeedUp ? 1.8f : 1.0f;

            this.method_5724(0.245f * speedMultiplier, new class_243(strafe, -1, forward));
            this.method_5784(class_1313.field_6308, this.method_18798());
            this.field_6007 = true;
        }
    }

    @Override
    public boolean method_5740() {
        return false;
    }

    protected class_241 getControlledRotation(class_1309 controllingPassenger) {
        return new class_241(controllingPassenger.method_36455() * 0.5f, controllingPassenger.method_36454());
    }

    @Override
    protected class_243 method_49482(class_1657 controllingPlayer, class_243 movementInput) {
        float f = controllingPlayer.field_6212 * 0.5f;
        float g = controllingPlayer.field_6250;
        if (g <= 0.0f) {
            g *= 0.25f;
        }
        return new class_243(f, 0.0, g);
    }

    @Override
    public void method_6078(class_1282 damageSource) {
        super.method_6078(damageSource);
        class_1937 world = this.method_37908();
        class_1542 itemEntity = new class_1542(world, this.method_23317(), this.method_23318(), this.method_23321(), new class_1799(RDBlocks.WHEEL_CHAIR));
        world.method_8649(itemEntity);
    }

    @Override
    public class_1269 method_5992(class_1657 player, class_1268 hand) {
        class_1937 world = player.method_37908();
        if (!this.method_5782() && !player.method_21823()) {
            if (!this.method_37908().field_9236) {
                player.method_5804(this);
            }
            return class_1269.field_5812;
        }
        return super.method_5992(player, hand);
    }

    public static class_5132 createAttributes() {
        return class_1429.method_61457()
                .method_26868(class_5134.field_23716, 20.0)
                .method_26868(class_5134.field_23719, 0.25)
                .method_26868(class_5134.field_23720, 0.15)
                .method_26868(class_5134.field_23718, 10.0)
                .method_26866();
    }

    @Override
    protected void method_5652(class_11372 view) {
        super.method_5652(view);
        view.method_71469("OwnerUUID", this.ownerUUID);
    }

    @Override
    protected void method_5749(class_11368 view) {
        super.method_5749(view);
        this.ownerUUID = view.method_71428("OwnerUUID", "null");
    }

    @Override
    public class_243 method_52538(class_1297 entity) {
        class_243 position = super.method_52538(entity);
        position = new class_243(position.field_1352, position.field_1351 - 0.5, position.field_1350);
        return position;
    }

    @Override
    public void method_6154(int strength) {

    }

    @Override
    public boolean method_6153() {
        return this.method_24828();
    }

    @Override
    public void method_6155(int height) {
        if (this.method_24828()) {
            this.method_5762(0, 0.42D, 0);
        }
    }


    @Override
    public void method_6156() {

    }
}
